@@ -355,7 +355,7 @@ windRose <- function(mydata, ws = "ws", wd = "wd", ws2 = NA, wd2 = NA,
 
   ## reset graphic parameters
   on.exit(trellis.par.set(
-    strip.background = current.strip,
+     
     fontsize = current.font
   ))
 
@@ -693,8 +693,8 @@ windRose <- function(mydata, ws = "ws", wd = "wd", ws2 = NA, wd2 = NA,
     if (length(id > 0)) tmp[id] <- 360
     tmp <- table(tmp) ## number of sectors spanned
     vars <- grep("Interval[1-9]", names(results)) ## the frequencies, without any calms
-    results[results[[wd]] != -999, vars] <-
-      results[results[[wd]] != -999, vars] * mean(tmp) / tmp
+    results[results[["wd"]] != -999, vars] <-
+      results[results[["wd"]] != -999, vars] * mean(tmp) / tmp
     return(results)
   }
 
